svn commit: samba r15881 - in branches/SAMBA_4_0/source/torture/raw: .

tridge at samba.org tridge at samba.org
Thu May 25 07:14:34 GMT 2006


Author: tridge
Date: 2006-05-25 07:14:33 +0000 (Thu, 25 May 2006)
New Revision: 15881

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=15881

Log:

fixed the RAW-ACLS test for 64 bit systems (was failing on ppc64)

Modified:
   branches/SAMBA_4_0/source/torture/raw/acls.c


Changeset:
Modified: branches/SAMBA_4_0/source/torture/raw/acls.c
===================================================================
--- branches/SAMBA_4_0/source/torture/raw/acls.c	2006-05-25 04:46:38 UTC (rev 15880)
+++ branches/SAMBA_4_0/source/torture/raw/acls.c	2006-05-25 07:14:33 UTC (rev 15881)
@@ -1559,12 +1559,14 @@
 	uint64_t desired_64;
 	uint32_t desired = 0, granted;
 	int i = 0;
+#define NO_BITS_HACK (((uint64_t)1)<<32)
 	uint64_t open_bits =
 		SEC_MASK_GENERIC |
 		SEC_FLAG_SYSTEM_SECURITY |
 		SEC_FLAG_MAXIMUM_ALLOWED |
 		SEC_STD_ALL |
-		SEC_FILE_ALL;
+		SEC_FILE_ALL | 
+		NO_BITS_HACK;
 	uint64_t get_owner_bits = SEC_MASK_GENERIC | SEC_FLAG_MAXIMUM_ALLOWED | SEC_STD_READ_CONTROL;
 	uint64_t set_owner_bits = SEC_GENERIC_ALL  | SEC_FLAG_MAXIMUM_ALLOWED | SEC_STD_WRITE_OWNER;
 	uint64_t get_group_bits = SEC_MASK_GENERIC | SEC_FLAG_MAXIMUM_ALLOWED | SEC_STD_READ_CONTROL;
@@ -1610,10 +1612,10 @@
 	/* 
 	 * now try each access_mask bit and no bit at all in a loop
 	 * and see what's allowed
 	 * NOTE: if i == 32 it means access_mask = 0
 	 */
 	for (i=0; i <= 32; i++) {
-		desired_64 = 1 << i;
+		desired_64 = ((uint64_t)1) << i;
 		desired = (uint32_t)desired_64;
 
 		/* first open the file with the desired access */
@@ -1610,10 +1612,10 @@
 	 * now try each access_mask bit and no bit at all in a loop
 	 * and see what's allowed
-	 * NOTE: if i == 32 it means access_mask = 0
+	 * NOTE: if i == 32 it means access_mask = 0 (see NO_BITS_HACK above)
 	 */
 	for (i=0; i <= 32; i++) {



More information about the samba-cvs mailing list